/////////////////////////////////////////////////////////////////////////////
// クライアントスクリプト用共通定義
// 作成：長田
// 記述言語：JavaScript
/////////////////////////////////////////////////////////////////////////////

//===========================================================================
// 定数定義

// ブラウザの種別
var BROWSER_TYPE_UNKNOWN = -1;
var BROWSER_TYPE_NAVIGATOR = 0;
var BROWSER_TYPE_IE = 1;

//===========================================================================


//===========================================================================
// 関数定義

/////////////////////////////////////////////////////////////////////////////
// 日付

// 指定された年がうるう年かチェックする
function isLeapYear(
	nYear)	// チェックする年（入力）
{
	var bLeap = ((nYear % 4) == 0);
	if (bLeap != false) {
		if ((nYear % 100) == 0) {
			bLeap = ((nYear % 400) == 0);
		}
	}
	return bLeap;
}

// 指定年月の日数を返す
function getDaysOfMonth(
	nYear,		//	西暦年（入力）
	nMonth)		//	月（入力）
{
	var nDays = 0;
	if (nMonth == 2) {
		nDays = (isLeapYear(nYear, nMonth) ? 29 : 28);
	}
	else {
		nDays = (nMonth <= 7 ? 30 + (nMonth % 2) : 31 - (nMonth % 2));
	}
	return nDays;
}

// 与えられた日付が正しいかチェックする
function checkDate(
	nYear,	// 西暦年（入力）
	nMonth,	// 月（入力）
	nDay)	// 日（入力）
{
	return ((1 <= nMonth && nMonth <= 12)
			&& (1 <= nDay && nDay <= getDaysOfMonth(nYear, nMonth)));
}

/////////////////////////////////////////////////////////////////////////////
// クッキー操作

// クッキーが使用可能かチェックする
// 注記：すでにクッキーが設定されている画面では使用しないこと。また実際に
// クッキーを設定する前に呼びだすこと
function isCookieEnabled()
{
	var bEnabled = false;
	with (document) {
		if (cookie.length == 0) {
			cookie = "Cookie=Accept?;";
		}
		bEnabled = (0 < cookie.length);
	}
	return bEnabled;
}

// クッキーの値を取得する
// 戻り値：クッキーの値
function getCookieValue(
	strCookieName)	// 値を取得するクッキーの名前（入力）
{
	var strCookieValue = "";

	var strCookie = document.cookie + ";";
	var nCookiePos = strCookie.indexOf(strCookieName, 0);
	if (0 <= nCookiePos) {
		var nValueStart = nCookiePos + strCookieName.length;
		strCookie = strCookie.substr(nValueStart);
		if (strCookie.charAt(0) == "=") {
			var nValueEnd = strCookie.indexOf(';');
			if (0 < nValueEnd) {
				strCookieValue = unescape(strCookie.substring(1, nValueEnd));
			}
		}
	}
	return strCookieValue;
}

// クッキー用の名前と値のペアを作成する
// 戻り値：作成した文字列
function makeCookiePair(
	strName,	// 名前（入力）
	strValue)	// 値（入力）
{
	return strName + "=" + strValue + ";";
}

// クッキーを設定する
function setCookie(
	strName,	// クッキーの名前（入力）
	strValue,	// 設定する値（入力）
	dtExpires,	// 破棄日時（入力）
	strPath,	// パス（入力）
	strDomain,	// ドメイン（入力）
	bSecure)	// （入力）
{
	var strCookie = makeCookiePair(strName, escape(strValue));
	if (dtExpires != null) {
		strCookie += makeCookiePair("expires", dtExpires.toGMTString());
	}
	if (strPath != null) {
		strCookie += makeCookiePair("path", strPath);
	}
	if (strDomain != null) {
		strCookie += makeCookiePair("domain", strDomain);
	}
	if (bSecure != false) {
		strCookie += "secure";
	}
	document.cookie = strCookie;
}

/////////////////////////////////////////////////////////////////////////////
// ブラウザ

// ブラウザの種別を返す
// 戻り値：取得したブラウザ種別
function getBrowserType()
{
	var nType = BROWSER_TYPE_UNKNOWN;
	var strBrowserName = navigator.appName;
	if (strBrowserName == "Netscape") {
		nType = BROWSER_TYPE_NAVIGATOR;
	}
	else if (strBrowserName == "Microsoft Internet Explorer") {
		nType = BROWSER_TYPE_IE;
	}
	return nType;
}

// ブラウザのバージョンを返す
// 戻り値：取得したブラウザ種別
function getBrowserVersion()
{
	var fVersion = 0;
	var nType = getBrowserType();
	if (nType == BROWSER_TYPE_IE) {
		// 互換性のためかどうかわからないがIEは自分自身の本当のバージョンを先頭に置かない。
		// しょうがないので文字列の中からそれを探す
		var strFind = "MSIE ";
		var nVerPos = navigator.appVersion.indexOf(strFind) + strFind.length;
		var strVersion = navigator.appVersion.substr(nVerPos);
		fVersion = parseFloat(strVersion);
	}
	else {
		// 素直に文字列先頭のバージョンを利用する
		fVersion = parseFloat(navigator.appVersion);
	}
	return fVersion;
}

// 別ウィンドウ表示でないときに指定URLを表示する
function showCorrectPage(
	strURL)	// 表示するURL（入力）
{
	with (window) {
		if (opener == null) {
			location.replace(strURL);
		}
	}
}


// フォームが存在するとき最初のフォームの最初のコントロールにフォーカスを設定する
function setFocustToFirstForm()
{
/*****
	if (0 < document.forms.length
	&& 0 < document.forms[0].elements.length) {
		document.forms[0].elements[0].focus();
	}
*****/
	if ( document.forms.length > 0 ) {
		with ( document.forms[0] ) {
			for ( var i =0;i < elements.length; i++ ) {		
				if ( "hidden" != elements[i].type ) {
					elements[i].focus();
					if ( "text" == elements[i].type ){
						elements[i].select();
					}
					break;
				}		
			}
		}
	}
}

/////////////////////////////////////////////////////////////////////////////
// ウィンドウ操作

// 定数・ファイルスコープ変数宣言
// ポップアップウィンドウの種別とそのオブジェクト保持用変数
// 学習者
var POPUPWND_SYLLABUS		= 0;	// 目次
var POPUPWND_GLOSSARY		= 1;	// 用語集
var POPUPWND_GUIDANCE		= 2;	// 学習室とITコースのガイダンス
var POPUPWND_SIMULATION		= 3;	// シミュレーション
var POPUPWND_INDEX			= 4;	// 索引
var POPUPWND_COURSEGUIDANCE	= 5;	// コースページのガイダンス(含ITコースヘルプ

// チュータ
var POPUPWND_EXAMPLEANSWER = 0;	// 模範解答

//　NL管理者
var POPUPWND_HEADCOMPANY = 0;	//上位企業選択

var awndPopup = new Array;

// URLを独立したウィンドウで開く
function openURLbyPopup(
	strName,	// 開くウィンドウの名前（入力）
	strURL,		// 表示するURL（入力）
	nWidth,		// 開くウィンドウの幅（入力）
	nHeight)	// 開くウィンドウの高さ（入力）
{
	// Netscape Communicator 4.7では第二引数（開いたウィンドウの名前）に
	// 2バイト文字を指定するとかなりの確率でウィンドウの作成に失敗する。
	// dependentは親ウィンドウクローズと同時に閉じるための指定。2000.1.7現在
	// 対応しているのはCommunicator4以降。
	var wndPopup = open(strURL,
						strName,
						"scrollbars,resizable,dependent,width="+ nWidth + ",height=" + nHeight);
	if (wndPopup != null) {
		if (wndPopup.opener == null) {
			wndPopup.opener = self;
		}
		wndPopup.focus();
	}
	return wndPopup;
}

// ポップアップウィンドウを表示する
function showPopup(
	nKind,		// 表示するポップアップウィンドウの種別（入力）
	strName,	// ポップアップウィンドウの名前（入力）
	strURL)		// ポップアップウィンドウのURL（入力）
{
	if (awndPopup[nKind] != null && awndPopup[nKind].closed == false) {
		var strTitle = awndPopup[nKind].document.title;
		awndPopup[nKind].location.href = strURL;
		awndPopup[nKind].document.title = strTitle;
		awndPopup[nKind].focus();
	}
	else {
		awndPopup[nKind] = openURLbyPopup(strName, strURL, 640, 400);
	}
}

// 表示中のポップアップウィンドウを閉じる
function closePopup()
{
	for (var nCount in awndPopup) {
		if (awndPopup[nCount] != null) {
			if (awndPopup[nCount].closed == false) {
				awndPopup[nCount].close();
			}
			awndPopup[nCount] = null;
		}
	}
}

/////////////////////////////////////////////////////////////////////////////
//	フォーカス初期化

function InitFocus()
{
	if ( document.forms.length > 0 ) {
		with ( document.forms[0] ) {
			for ( var i =0;i < elements.length; i++ ) {		
				if ( "hidden" != elements[i].type ) {
					elements[i].focus();
					break;
				}		
			}
		}
	}
}

/////////////////////////////////////////////////////////////////////////////
//	入力データチェック関数

function IsEmpty( arValue )
{
	for ( var i = 0; i < arValue.length; i++ )
	{
		if ( 0 == arValue[i].length )
			return true;
	}
	
	return false;
}

/////////////////////////////////////////////////////////////////////////////
//	ステータスバー

// setStatusMsg : ステータスバーにメッセージを設定する
//	引数：	strMsg　= 設定するメッセージ
function setStatusMsg( strMsg )
{
	status = strMsg;
	return true;
}

// clearStatusMsg ステータスバーのメッセージを消去する
function clearStatusMsg()
{
	status = defaultStatus;
	return true;
}
//===========================================================================


// メディアプレーヤーのコントロールを作成する
// （クリックなしでアクティブのするための外部スクリプトによる生成）
function CreateMediaPlayerObject(DivID, WIDTH, HEIGHT, URL)
{
  var d = document.getElementById(DivID);
  d.innerHTML = 
    "<object classid='clsid:6BF52A52-394A-11D3-B153-00C04F79FAA6'"+
    " width='" + WIDTH + "'"+
    " height='" + HEIGHT + "'>"+
    "  <param name='URL' value='" + URL + "' />"+
    "  <param name='AutoStart' value='false' />"+
    "  <param name='AutoRewind' value='true' />"+
    "  <param name='ShowControls' value='true' />"+
    "</object>";
}

// Flashのコントロールを作成する
// （クリックなしでアクティブにするための外部スクリプトによる生成）
function CreateFlashObject(DivID, WIDTH, HEIGHT, LOOP, URL, IsSSL)
{
  var d = document.getElementById(DivID);
  d.innerHTML = 
    "<object classid='clsid:D27CDB6E-AE6D-11cf-96B8-444553540000'"+
    "  codebase='" + (IsSSL? "https":"http")+ "://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#3,0,0,0'" +
    "  width='" + WIDTH + "'"+
    "  height='" + HEIGHT + "'>"+
    "  <param name='src' value='" + URL + "' />"+
    "  <param name='loop' value='" + LOOP + "' />"+
    "  <param name='allowFullScreen' value='true' />"+
    "  <embed pluginspage='http://www.macromedia.com/shockwave/download/'"+
    "    type='application/x-shockwave-flash'"+
    "    src='" + URL + "'"+
    "    width='" + WIDTH + "'"+
    "    height='" + HEIGHT + "'"+
    "    loop='" + LOOP + "'"+
    "    allowFullScreen='true' />"+　
    "</object>";
}


function CreateRadarChart(DivID, WIDTH, HEIGHT, LOOP, URL, IsSSL)
{
    var div = $("#" + DivID);
    var iframe = $("<iframe/>");
    iframe.attr("src", URL.replace(/amp;/ig,'&') + "&width=" + WIDTH + "&height=" + HEIGHT);
    iframe.attr("width", WIDTH + 10);
    iframe.attr("height", HEIGHT + 10);
    iframe.attr("frameborder", "0");
    iframe.attr("scrolling", "no");
    
    div.append(iframe);
    

}

// FlashのスクリプトからWindowをクローズするときに呼ばれる関数
function NLXCloseWindow(){
	window.close();
}

